@@ -654,6 +654,18 @@ atspi_relation_type_get_type (void)
 			{ ATSPI_RELATION_DESCRIBED_BY,
 			  "ATSPI_RELATION_DESCRIBED_BY",
 			  "described-by" },
+			{ ATSPI_RELATION_DETAILS,
+			  "ATSPI_RELATION_DETAILS",
+			  "details" },
+			{ ATSPI_RELATION_DETAILS_FOR,
+			  "ATSPI_RELATION_DETAILS_FOR",
+			  "details-for" },
+			{ ATSPI_RELATION_ERROR_MESSAGE,
+			  "ATSPI_RELATION_ERROR_MESSAGE",
+			  "error-message" },
+			{ ATSPI_RELATION_ERROR_FOR,
+			  "ATSPI_RELATION_ERROR_FOR",
+			  "error-for" },
 			{ ATSPI_RELATION_LAST_DEFINED,
 			  "ATSPI_RELATION_LAST_DEFINED",
 			  "last-defined" },
